<%inherit file="../base/base.html" /> <%namespace file="../base/base.html" import="header, setup_margin_labels" /> <%block name="extra_meta"> ${ setup_margin_labels(title) }
${ header(complete_header, title, report.get_subtitle(), notes) } % if report.has_in_payments():

### ${ _("Input Payments:") }

<%include file="sales.html" /> <%include file="lonely-payments.html" args="payments=report.lonely_in_payments" /> % endif % if report.has_out_payments():

### ${ _("Output Payments:") }

<%include file="purchases.html" /> <%include file="lonely-payments.html" args="payments=report.lonely_out_payments" /> <%include file="return-sales.html" /> % endif % if report.has_till_entries():

### ${ _("Till Supply/Removal Operations:") }

<%include file="supplies.html" /> <%include file="removals.html" /> % endif

### ${ _("Summary:") }

<%include file="summary.html" />
<%include file="card-summary.html" />

### ${ _("Observations:") }

% if report.tills:

% for till in report.tills: % if till.observations:
- ${ format_date(till.opening_date) } ${ till.observations }
% endif % endfor

% else:
% endif

${ _("Signature") } ${_("Verified by") }